import sys
import os
sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))

from XMFlib.PairProbML import PairProbPredictor

# Instantiate the predictor
predictor = PairProbPredictor()

# Run prediction with example values
result = predictor.predict(
    facet=100,
    interaction_energy=0.2,
    temperature=400,
    main_coverage=0.5
)

print("Predicted probabilities:", result)


import torch.nn as nn

class MLP(nn.Module):
    def __init__(self, num_inputs=2, num_outputs=3): # default parameters
        super(MLP, self).__init__()
        self.net = nn.Sequential(
            nn.Linear(num_inputs, 128),
            nn.ReLU(),
            nn.Linear(128, 72),
            nn.ReLU(),
            nn.Linear(72, 36),
            nn.ReLU(),
            nn.Linear(36, 8),
            nn.ReLU(),
            nn.Linear(8, num_outputs)
        )

    def forward(self, x):
        return self.net(x)